import { IRepository } from 'aws-cdk-lib/aws-ecr';
import { DockerImageAsset } from 'aws-cdk-lib/aws-ecr-assets';
import { Construct } from 'constructs';
export interface SociIndexV2BuildProps {
    /**
     * The ECR repository your container image is stored.
     * You can only specify a repository in the same environment (account/region).
     * The index artifact will be uploaded to this repository.
     */
    readonly repository: IRepository;
    /**
     * The tag of the container image you want to build index for.
     */
    readonly inputImageTag: string;
    /**
     * The tag of the output container image embedded with SOCI index.
     *
     * @default `${inputImageTag}-soci`
     */
    readonly outputImageTag?: string;
}
/**
 * Build and publish a SOCI index for a container image.
 * A SOCI index helps start Fargate tasks faster in some cases.
 * Please read the following document for more details: https://docs.aws.amazon.com/AmazonECS/latest/userguide/container-considerations.html
 */
export declare class SociIndexV2Build extends Construct {
    /**
     * A utility method to create a SociIndexBuild construct from a DockerImageAsset instance.
     */
    static fromDockerImageAsset(scope: Construct, id: string, imageAsset: DockerImageAsset): SociIndexV2Build;
    readonly repository: IRepository;
    readonly outputImageTag: string;
    constructor(scope: Construct, id: string, props: SociIndexV2BuildProps);
    /**
     * Get the instance of image embedded with SOCI v2 index for an ECS task definition.
     * When using this image returned from this function, your deployment waits until
     * the index build complete and then start deploying after the image with index ready.
     */
    toEcsDockerImageCode(): import("aws-cdk-lib/aws-ecs").EcrImage;
}
